/*
*  With infinite thanks to:
*  https://github.com/reinholtz/hershey-fonts-with-unicode
*
*  Converted:
*     https://github.com/reinholtz/hershey-fonts-with-unicode/blob/master/hersheyunicodemap.csv
*
*/
typedef struct _giza_hershey_to_utf_entry {
int const   hershey;
char const* utf;
} giza_hershey_to_utf_entry;

static giza_hershey_to_utf_entry const giza_hershey_to_utf[] = {
{1, "A"},
{2, "B"},
{3, "C"},
{4, "D"},
{5, "E"},
{6, "F"},
{7, "G"},
{8, "H"},
{9, "I"},
{10, "J"},
{11, "K"},
{12, "L"},
{13, "M"},
{14, "N"},
{15, "O"},
{16, "P"},
{17, "Q"},
{18, "R"},
{19, "S"},
{20, "T"},
{21, "U"},
{22, "V"},
{23, "W"},
{24, "X"},
{25, "Y"},
{26, "Z"},
{27, "\u0391"},
{28, "\u0392"},
{29, "\u0393"},
{30, "\u0394"},
{31, "\u0395"},
{32, "\u0396"},
{33, "\u0397"},
{34, "\u0398"},
{35, "\u0399"},
{36, "\u039a"},
{37, "\u039b"},
{38, "\u039c"},
{39, "\u039d"},
{40, "\u039e"},
{41, "\u039f"},
{42, "\u03a0"},
{43, "\u03a1"},
{44, "\u03a3"},
{45, "\u03a4"},
{46, "\u03a5"},
{47, "\u03a6"},
{48, "\u03a7"},
{49, "\u03a8"},
{50, "\u03a9"},
{197, "\u200b"},
{198, "\u2002"},
{199, "\u2003"},
{200, "0"},
{201, "1"},
{202, "2"},
{203, "3"},
{204, "4"},
{205, "5"},
{206, "6"},
{207, "7"},
{208, "8"},
{209, "9"},
{210, "."},
{211, ","},
{212, ":"},
{213, ";"},
{214, "!"},
{215, "?"},
{216, "\u2032"},
{217, "\u2033"},
{218, "\u00b0"},
{219, "$"},
{220, "/"},
{221, "("},
{222, ")"},
{223, "|"},
{224, "-"},
{225, "+"},
{226, "="},
{227, "\u00d7"},
{228, "*"},
{229, "\u00b7"},
{230, "\u2018"},
{231, "\u2019"},
{232, "\u2192"},
{233, "#"},
{234, "&"},
{235, "\u2311"},
{273, "\u00ae"},
{274, "\u00a9"},
{501, "A"},
{502, "B"},
{503, "C"},
{504, "D"},
{505, "E"},
{506, "F"},
{507, "G"},
{508, "H"},
{509, "I"},
{510, "J"},
{511, "K"},
{512, "L"},
{513, "M"},
{514, "N"},
{515, "O"},
{516, "P"},
{517, "Q"},
{518, "R"},
{519, "S"},
{520, "T"},
{521, "U"},
{522, "V"},
{523, "W"},
{524, "X"},
{525, "Y"},
{526, "Z"},
{527, "\u0391"},
{528, "\u0392"},
{529, "\u0393"},
{530, "\u0394"},
{531, "\u0395"},
{532, "\u0396"},
{533, "\u0397"},
{534, "\u0398"},
{535, "\u0399"},
{536, "\u039a"},
{537, "\u039b"},
{538, "\u039c"},
{539, "\u039d"},
{540, "\u039e"},
{541, "\u039f"},
{542, "\u03a0"},
{543, "\u03a1"},
{544, "\u03a3"},
{545, "\u03a4"},
{546, "\u03a5"},
{547, "\u03a6"},
{548, "\u03a7"},
{549, "\u03a8"},
{550, "\u03a9"},
{551, "A"},
{552, "B"},
{553, "C"},
{554, "D"},
{555, "E"},
{556, "F"},
{557, "G"},
{558, "H"},
{559, "I"},
{560, "J"},
{561, "K"},
{562, "L"},
{563, "M"},
{564, "N"},
{565, "O"},
{566, "P"},
{567, "Q"},
{568, "R"},
{569, "S"},
{570, "T"},
{571, "U"},
{572, "V"},
{573, "W"},
{574, "X"},
{575, "Y"},
{576, "Z"},
{583, "\u2207"},
{601, "a"},
{602, "b"},
{603, "c"},
{604, "d"},
{605, "e"},
{606, "f"},
{607, "g"},
{608, "h"},
{609, "i"},
{610, "j"},
{611, "k"},
{612, "l"},
{613, "m"},
{614, "n"},
{615, "o"},
{616, "p"},
{617, "q"},
{618, "r"},
{619, "s"},
{620, "t"},
{621, "u"},
{622, "v"},
{623, "w"},
{624, "x"},
{625, "y"},
{626, "z"},
{627, "\u03b1"},
{628, "\u03b2"},
{629, "\u03b3"},
{630, "\u03b4"},
{631, "\u03b5"},
{632, "\u03b6"},
{633, "\u03b7"},
{634, "\u03b8"},
{635, "\u03b9"},
{636, "\u03ba"},
{637, "\u03bb"},
{638, "\u03bc"},
{639, "\u03bd"},
{640, "\u03be"},
{641, "\u03bf"},
{642, "\u03c0"},
{643, "\u03c1"},
{644, "\u03c3"},
{645, "\u03c4"},
{646, "\u03c5"},
{647, "\u03c6"},
{648, "\u03c7"},
{649, "\u03c8"},
{650, "\u03c9"},
{651, "a"},
{652, "b"},
{653, "c"},
{654, "d"},
{655, "e"},
{656, "f"},
{657, "g"},
{658, "h"},
{659, "i"},
{660, "j"},
{661, "k"},
{662, "l"},
{663, "m"},
{664, "n"},
{665, "o"},
{666, "p"},
{667, "q"},
{668, "r"},
{669, "s"},
{670, "t"},
{671, "u"},
{672, "v"},
{673, "w"},
{674, "x"},
{675, "y"},
{676, "z"},
{677, "\ufffd"},
{683, "\ufffd"},
{684, "\u03b5"},
{685, "\u03b8"},
{686, "\u03d5"},
{687, "\u03da"},
{697, "\u200b"},
{698, "\u2002"},
{699, "\u2003"},
{700, "0"},
{701, "1"},
{702, "2"},
{703, "3"},
{704, "4"},
{705, "5"},
{706, "6"},
{707, "7"},
{708, "8"},
{709, "9"},
{710, "."},
{711, ","},
{712, ":"},
{713, ";"},
{714, "!"},
{715, "?"},
{716, "\u2032"},
{717, "\u2033"},
{718, "\u00b0"},
{719, "$"},
{720, "/"},
{721, "("},
{722, ")"},
{723, "|"},
{724, "-"},
{725, "+"},
{726, "="},
{727, "\u00d7"},
{728, "*"},
{729, "\u00b7"},
{730, "\u2018"},
{731, "\u2019"},
{732, "\u2192"},
{733, "#"},
{734, "&"},
{735, "\u2311"},
{737, "\u2225"},
{738, "\u27c2"},
{739, "\u2220"},
{740, "\u2e2b"},
{741, "\u2664"},
{742, "\u2661"},
{743, "\u2662"},
{744, "\u2667"},
{745, "\u2618"},
{746, "\u269c"},
{750, "\ufffd"},
{751, "\ufffd"},
{752, "\ufffd"},
{753, "\ufffd"},
{754, "\ufffd"},
{755, "\ufffd"},
{756, "\ufffd"},
{757, "\ufffd"},
{758, "\ufffd"},
{759, "\ufffd"},
{760, "\ufffd"},
{761, "\ufffd"},
{762, "\ufffd"},
{763, "\ufffd"},
{764, "\ufffd"},
{765, "\ufffd"},
{766, "\ufffd"},
{767, "\ufffd"},
{768, "\ufffd"},
{796, "\ufffd"},
{797, "\ufffd"},
{798, "\ufffd"},
{799, "\ufffd"},
{800, "\ufffd"},
{801, "\ufffd"},
{802, "\ufffd"},
{803, "\ufffd"},
{804, "\ufffd"},
{805, "\ufffd"},
{806, "\ufffd"},
{807, "\ufffd"},
{808, "\ufffd"},
{809, "\ufffd"},
{810, "\ufffd"},
{811, "\ufffd"},
{812, "\ufffd"},
{813, "\ufffd"},
{814, "\ufffd"},
{815, "\ufffd"},
{816, "\ufffd"},
{817, "\ufffd"},
{818, "\ufffd"},
{819, "\ufffd"},
{820, "\ufffd"},
{821, "\ufffd"},
{822, "\ufffd"},
{823, "\ufffd"},
{824, "\ufffd"},
{825, "\ufffd"},
{826, "\ufffd"},
{827, "\ufffd"},
{828, "\ufffd"},
{829, "\ufffd"},
{830, "\ufffd"},
{831, "\ufffd"},
{832, "\ufffd"},
{833, "\ufffd"},
{834, "\ufffd"},
{840, "\ufffd"},
{841, "\ufffd"},
{842, "\ufffd"},
{843, "\ufffd"},
{844, "\ufffd"},
{845, "\ufffd"},
{846, "\ufffd"},
{847, "\ufffd"},
{850, "\ufffd"},
{851, "\ufffd"},
{852, "\ufffd"},
{853, "\ufffd"},
{854, "\ufffd"},
{855, "\ufffd"},
{856, "\ufffd"},
{857, "\ufffd"},
{860, "\ufffd"},
{861, "\ufffd"},
{862, "\ufffd"},
{863, "\ufffd"},
{864, "\ufffd"},
{865, "\ufffd"},
{866, "\ufffd"},
{867, "\ufffd"},
{868, "\ufffd"},
{869, "\ufffd"},
{870, "\ufffd"},
{871, "\ufffd"},
{872, "\ufffd"},
{873, "\ufffd"},
{874, "\ufffd"},
{899, "\ufffd"},
{900, "\ufffd"},
{901, "\ufffd"},
{902, "\ufffd"},
{903, "\ufffd"},
{904, "\ufffd"},
{905, "\ufffd"},
{906, "\ufffd"},
{907, "\ufffd"},
{908, "\ufffd"},
{909, "\ufffd"},
{997, "\ufffd"},
{998, "\ufffd"},
{999, "\ufffd"},
{1001, "A"},
{1002, "B"},
{1003, "C"},
{1004, "D"},
{1005, "E"},
{1006, "F"},
{1007, "G"},
{1008, "H"},
{1009, "I"},
{1010, "J"},
{1011, "K"},
{1012, "L"},
{1013, "M"},
{1014, "N"},
{1015, "O"},
{1016, "P"},
{1017, "Q"},
{1018, "R"},
{1019, "S"},
{1020, "T"},
{1021, "U"},
{1022, "V"},
{1023, "W"},
{1024, "X"},
{1025, "Y"},
{1026, "Z"},
{1027, "\u0391"},
{1028, "\u0392"},
{1029, "\u0393"},
{1030, "\u0394"},
{1031, "\u0395"},
{1032, "\u0396"},
{1033, "\u0397"},
{1034, "\u0398"},
{1035, "\u0399"},
{1036, "\u039a"},
{1037, "\u039b"},
{1038, "\u039c"},
{1039, "\u039d"},
{1040, "\u039e"},
{1041, "\u039f"},
{1042, "\u03a0"},
{1043, "\u03a1"},
{1044, "\u03a3"},
{1045, "\u03a4"},
{1046, "\u03a5"},
{1047, "\u03a6"},
{1048, "\u03a7"},
{1049, "\u03a8"},
{1050, "\u03a9"},
{1051, "A"},
{1052, "B"},
{1053, "C"},
{1054, "D"},
{1055, "E"},
{1056, "F"},
{1057, "G"},
{1058, "H"},
{1059, "I"},
{1060, "J"},
{1061, "K"},
{1062, "L"},
{1063, "M"},
{1064, "N"},
{1065, "O"},
{1066, "P"},
{1067, "Q"},
{1068, "R"},
{1069, "S"},
{1070, "T"},
{1071, "U"},
{1072, "V"},
{1073, "W"},
{1074, "X"},
{1075, "Y"},
{1076, "Z"},
{1101, "a"},
{1102, "b"},
{1103, "c"},
{1104, "d"},
{1105, "e"},
{1106, "f"},
{1107, "g"},
{1108, "h"},
{1109, "i"},
{1110, "j"},
{1111, "k"},
{1112, "l"},
{1113, "m"},
{1114, "n"},
{1115, "o"},
{1116, "p"},
{1117, "q"},
{1118, "r"},
{1119, "s"},
{1120, "t"},
{1121, "u"},
{1122, "v"},
{1123, "w"},
{1124, "x"},
{1125, "y"},
{1126, "z"},
{1127, "\u03b1"},
{1128, "\u03b2"},
{1129, "\u03b3"},
{1130, "\u03b4"},
{1131, "\u03b5"},
{1132, "\u03b6"},
{1133, "\u03b7"},
{1134, "\u03b8"},
{1135, "\u03b9"},
{1136, "\u03ba"},
{1137, "\u03bb"},
{1138, "\u03bc"},
{1139, "\u03bd"},
{1140, "\u03be"},
{1141, "\u03bf"},
{1142, "\u03c0"},
{1143, "\u03c1"},
{1144, "\u03c3"},
{1145, "\u03c4"},
{1146, "\u03c5"},
{1147, "\u03c6"},
{1148, "\u03c7"},
{1149, "\u03c8"},
{1150, "\u03c9"},
{1151, "a"},
{1152, "b"},
{1153, "c"},
{1154, "d"},
{1155, "e"},
{1156, "f"},
{1157, "g"},
{1158, "h"},
{1159, "i"},
{1160, "j"},
{1161, "k"},
{1162, "l"},
{1163, "m"},
{1164, "n"},
{1165, "o"},
{1166, "p"},
{1167, "q"},
{1168, "r"},
{1169, "s"},
{1170, "t"},
{1171, "u"},
{1172, "v"},
{1173, "w"},
{1174, "x"},
{1175, "y"},
{1176, "z"},
{1177, "\ufb00"},
{1178, "\ufb01"},
{1179, "\ufb02"},
{1180, "\ufb03"},
{1181, "\ufb04"},
{1182, "\ufffd"},
{1184, "\u03b5"},
{1185, "\u03b8"},
{1186, "\u03d5"},
{1187, "\u03da"},
{1191, "\ufb00"},
{1192, "\ufb01"},
{1193, "\ufb02"},
{1194, "\ufb03"},
{1195, "\ufb04"},
{1196, "\ufffd"},
{1197, "\u200b"},
{1198, "\u2002"},
{1199, "\u2003"},
{1200, "0"},
{1201, "1"},
{1202, "2"},
{1203, "3"},
{1204, "4"},
{1205, "5"},
{1206, "6"},
{1207, "7"},
{1208, "8"},
{1209, "9"},
{1210, "."},
{1211, ","},
{1212, ":"},
{1213, ";"},
{1214, "!"},
{1215, "?"},
{1216, "\u2032"},
{1217, "\u2033"},
{1218, "\u00b0"},
{1219, "*"},
{1220, "/"},
{1221, "("},
{1222, ")"},
{1223, "["},
{1224, "]"},
{1225, "{"},
{1226, "}"},
{1227, "\u27e8"},
{1228, "\u27e9"},
{1229, "|"},
{1230, "\u2225"},
{1231, "\u2212"},
{1232, "+"},
{1233, "\u00b1"},
{1234, "\u2213"},
{1235, "\u2a2f"},
{1236, "\u22c5"},
{1237, "\u00f7"},
{1238, "="},
{1239, "\u2260"},
{1240, "\u2261"},
{1241, "<"},
{1242, ">"},
{1243, "\u2266"},
{1244, "\u2267"},
{1245, "\u221d"},
{1246, "\u223c"},
{1247, "\u0302"},
{1248, "\u0300"},
{1249, "\u0301"},
{1250, "\u0306"},
{1251, "\u0313"},
{1252, "\u0312"},
{1253, "\u0314"},
{1254, "\u031b"},
{1256, "\u2282"},
{1257, "\u222a"},
{1258, "\u2283"},
{1259, "\u2229"},
{1260, "\u2208"},
{1261, "\u2192"},
{1262, "\u2191"},
{1263, "\u2190"},
{1264, "\u2193"},
{1265, "Y"},
{1266, "\u2207"},
{1267, "\u221a"},
{1268, "\u222b"},
{1269, "\u222e"},
{1270, "\u221e"},
{1271, "%"},
{1272, "&"},
{1273, "@"},
{1274, "$"},
{1275, "#"},
{1276, "\u00a7"},
{1277, "\u2020"},
{1278, "\u2021"},
{1279, "\u2203"},
{1281, "\u0e82"},
{1282, "\u263f"},
{1283, "\ufffd"},
{1284, "\u23da"},
{1285, "\ufffd"},
{1286, "\u2643"},
{1287, "\u2644"},
{1288, "\u2645"},
{1289, "\u2646"},
{1290, "\u2647"},
{1291, "\u263d"},
{1292, "\u2604"},
{1293, "\u066d"},
{1294, "\u260a"},
{1295, "\u260b"},
{1401, "\u03a0"},
{1402, "\u03a3"},
{1403, "("},
{1404, ")"},
{1405, "["},
{1406, "]"},
{1407, "{"},
{1408, "}"},
{1409, "\u23b0"},
{1410, "\u23b1"},
{1411, "\u221a"},
{1412, "\u222b"},
{2001, "A"},
{2002, "B"},
{2003, "C"},
{2004, "D"},
{2005, "E"},
{2006, "F"},
{2007, "G"},
{2008, "H"},
{2009, "I"},
{2010, "J"},
{2011, "K"},
{2012, "L"},
{2013, "M"},
{2014, "N"},
{2015, "O"},
{2016, "P"},
{2017, "Q"},
{2018, "R"},
{2019, "S"},
{2020, "T"},
{2021, "U"},
{2022, "V"},
{2023, "W"},
{2024, "X"},
{2025, "Y"},
{2026, "Z"},
{2027, "\u0391"},
{2028, "\u0392"},
{2029, "\u0393"},
{2030, "\u0394"},
{2031, "\u0395"},
{2032, "\u0396"},
{2033, "\u0397"},
{2034, "\u0398"},
{2035, "\u0399"},
{2036, "\u039a"},
{2037, "\u039b"},
{2038, "\u039c"},
{2039, "\u039d"},
{2040, "\u039e"},
{2041, "\u039f"},
{2042, "\u03a0"},
{2043, "\u03a1"},
{2044, "\u03a3"},
{2045, "\u03a4"},
{2046, "\u03a5"},
{2047, "\u03a6"},
{2048, "\u03a7"},
{2049, "\u03a8"},
{2050, "\u03a9"},
{2051, "A"},
{2052, "B"},
{2053, "C"},
{2054, "D"},
{2055, "E"},
{2056, "F"},
{2057, "G"},
{2058, "H"},
{2059, "I"},
{2060, "J"},
{2061, "K"},
{2062, "L"},
{2063, "M"},
{2064, "N"},
{2065, "O"},
{2066, "P"},
{2067, "Q"},
{2068, "R"},
{2069, "S"},
{2070, "T"},
{2071, "U"},
{2072, "V"},
{2073, "W"},
{2074, "X"},
{2075, "Y"},
{2076, "Z"},
{2077, "\u2135"},
{2101, "a"},
{2102, "b"},
{2103, "c"},
{2104, "d"},
{2105, "e"},
{2106, "f"},
{2107, "g"},
{2108, "h"},
{2109, "i"},
{2110, "j"},
{2111, "k"},
{2112, "l"},
{2113, "m"},
{2114, "n"},
{2115, "o"},
{2116, "p"},
{2117, "q"},
{2118, "r"},
{2119, "s"},
{2120, "t"},
{2121, "u"},
{2122, "v"},
{2123, "w"},
{2124, "x"},
{2125, "y"},
{2126, "z"},
{2127, "\u03b1"},
{2128, "\u03b2"},
{2129, "\u03b3"},
{2130, "\u03b4"},
{2131, "\u03b5"},
{2132, "\u03b6"},
{2133, "\u03b7"},
{2134, "\u03b8"},
{2135, "\u03b9"},
{2136, "\u03ba"},
{2137, "\u03bb"},
{2138, "\u03bc"},
{2139, "\u03bd"},
{2140, "\u03be"},
{2141, "\u03bf"},
{2142, "\u03c0"},
{2143, "\u03c1"},
{2144, "\u03c3"},
{2145, "\u03c4"},
{2146, "\u03c5"},
{2147, "\u03c6"},
{2148, "\u03c7"},
{2149, "\u03c8"},
{2150, "\u03c9"},
{2151, "a"},
{2152, "b"},
{2153, "c"},
{2154, "d"},
{2155, "e"},
{2156, "f"},
{2157, "g"},
{2158, "h"},
{2159, "i"},
{2160, "j"},
{2161, "k"},
{2162, "l"},
{2163, "m"},
{2164, "n"},
{2165, "o"},
{2166, "p"},
{2167, "q"},
{2168, "r"},
{2169, "s"},
{2170, "t"},
{2171, "u"},
{2172, "v"},
{2173, "w"},
{2174, "x"},
{2175, "y"},
{2176, "z"},
{2177, "\ufb00"},
{2178, "\ufb01"},
{2179, "\ufb02"},
{2180, "\ufb03"},
{2181, "\ufb04"},
{2182, "\ufffd"},
{2184, "\u03b5"},
{2185, "\u03b8"},
{2186, "\u03d5"},
{2187, "\u03da"},
{2190, "\u2118"},
{2191, "\ufb00"},
{2192, "\ufb01"},
{2193, "\ufb02"},
{2194, "\ufb03"},
{2195, "\ufb04"},
{2196, "\ufffd"},
{2197, "\u200b"},
{2198, "\u2002"},
{2199, "\u2003"},
{2200, "0"},
{2201, "1"},
{2202, "2"},
{2203, "3"},
{2204, "4"},
{2205, "5"},
{2206, "6"},
{2207, "7"},
{2208, "8"},
{2209, "9"},
{2210, "."},
{2211, ","},
{2212, ":"},
{2213, ";"},
{2214, "!"},
{2215, "?"},
{2216, "\u2032"},
{2217, "\u2033"},
{2218, "\u00b0"},
{2219, "*"},
{2220, "/"},
{2221, "("},
{2222, ")"},
{2223, "["},
{2224, "]"},
{2225, "{"},
{2226, "}"},
{2227, "\u27e8"},
{2228, "\u27e9"},
{2229, "|"},
{2230, "\u2225"},
{2231, "\u2212"},
{2232, "+"},
{2233, "\u00b1"},
{2234, "\u2213"},
{2235, "\u2a2f"},
{2236, "\u22c5"},
{2237, "\u00f7"},
{2238, "="},
{2239, "\u2260"},
{2240, "\u2261"},
{2241, "<"},
{2242, ">"},
{2243, "\u2266"},
{2244, "\u2267"},
{2245, "\u221d"},
{2246, "\u223c"},
{2247, "\u0302"},
{2248, "\u0300"},
{2249, "\u0301"},
{2250, "\u0306"},
{2251, "\u0313"},
{2252, "\u0312"},
{2253, "\u0314"},
{2254, "\u031b"},
{2255, "\u221a"},
{2256, "\u2282"},
{2257, "\u222a"},
{2258, "\u2283"},
{2259, "\u2229"},
{2260, "\u2208"},
{2261, "\u2192"},
{2262, "\u2191"},
{2263, "\u2190"},
{2264, "\u2193"},
{2265, "Y"},
{2266, "\u2207"},
{2267, "\u221a"},
{2268, "\u222b"},
{2269, "\u222e"},
{2270, "\u221e"},
{2271, "%"},
{2272, "&"},
{2273, "@"},
{2274, "$"},
{2275, "#"},
{2276, "\u00a7"},
{2277, "\u2020"},
{2278, "\u2021"},
{2279, "\u2203"},
{2281, "\u2609"},
{2282, "\u263f"},
{2283, "\u2640"},
{2284, "\u2641"},
{2285, "\u2642"},
{2286, "\u2643"},
{2287, "\u2644"},
{2288, "\u26e2"},
{2289, "\u2646"},
{2290, "\u2647"},
{2291, "\u263e"},
{2292, "\u2604"},
{2293, "\u066d"},
{2294, "\u260a"},
{2295, "\u260b"},
{2301, "\u2648"},
{2302, "\u2649"},
{2303, "\u264a"},
{2304, "\u264b"},
{2305, "\u264c"},
{2306, "\u264d"},
{2307, "\u264e"},
{2308, "\U0001f982"},
{2309, "\u2650"},
{2310, "\ufffd"},
{2311, "\u2652"},
{2312, "\u2653"},
{2317, "\u00b7"},
{2318, "\ufffd"},
{2319, "\ufffd"},
{2320, "\U0001d15d"},
{2321, "\U0001d15e"},
{2322, "\u2669"},
{2323, "\u266f"},
{2324, "\u266e"},
{2325, "\u266d"},
{2326, "\U0001d13b"},
{2327, "\U0001d13c"},
{2328, "\U0001d13d"},
{2329, "\U0001d13e"},
{2330, "\U0001d11e"},
{2331, "\U0001d122"},
{2332, "\U0001d121"},
{2367, "\u00b7"},
{2368, "\ufffd"},
{2369, "\ufffd"},
{2370, "\U0001d15d"},
{2371, "\U0001d15e"},
{2372, "\u2669"},
{2373, "\u266f"},
{2374, "\u266e"},
{2375, "\u266d"},
{2376, "\U0001d13b"},
{2377, "\U0001d13c"},
{2378, "\U0001d13d"},
{2379, "\U0001d13e"},
{2380, "\U0001d11e"},
{2381, "\U0001d122"},
{2382, "\ufffd"},
{2401, "\u03a0"},
{2402, "\u03a3"},
{2403, "("},
{2404, ")"},
{2405, "["},
{2406, "]"},
{2407, "{"},
{2408, "}"},
{2409, "\u23b0"},
{2410, "\u23b1"},
{2411, "\u221a"},
{2412, "\u222b"},
{2501, "A"},
{2502, "B"},
{2503, "C"},
{2504, "D"},
{2505, "E"},
{2506, "F"},
{2507, "G"},
{2508, "H"},
{2509, "I"},
{2510, "J"},
{2511, "K"},
{2512, "L"},
{2513, "M"},
{2514, "N"},
{2515, "O"},
{2516, "P"},
{2517, "Q"},
{2518, "R"},
{2519, "S"},
{2520, "T"},
{2521, "U"},
{2522, "V"},
{2523, "W"},
{2524, "X"},
{2525, "Y"},
{2526, "Z"},
{2551, "A"},
{2552, "B"},
{2553, "C"},
{2554, "D"},
{2555, "E"},
{2556, "F"},
{2557, "G"},
{2558, "H"},
{2559, "I"},
{2560, "J"},
{2561, "K"},
{2562, "L"},
{2563, "M"},
{2564, "N"},
{2565, "O"},
{2566, "P"},
{2567, "Q"},
{2568, "R"},
{2569, "S"},
{2570, "T"},
{2571, "U"},
{2572, "V"},
{2573, "W"},
{2574, "X"},
{2575, "Y"},
{2576, "Z"},
{2601, "a"},
{2602, "b"},
{2603, "c"},
{2604, "d"},
{2605, "e"},
{2606, "f"},
{2607, "g"},
{2608, "h"},
{2609, "i"},
{2610, "j"},
{2611, "k"},
{2612, "l"},
{2613, "m"},
{2614, "n"},
{2615, "o"},
{2616, "p"},
{2617, "q"},
{2618, "r"},
{2619, "s"},
{2620, "t"},
{2621, "u"},
{2622, "v"},
{2623, "w"},
{2624, "x"},
{2625, "y"},
{2626, "z"},
{2651, "a"},
{2652, "b"},
{2653, "c"},
{2654, "d"},
{2655, "e"},
{2656, "f"},
{2657, "g"},
{2658, "h"},
{2659, "i"},
{2660, "j"},
{2661, "k"},
{2662, "l"},
{2663, "m"},
{2664, "n"},
{2665, "o"},
{2666, "p"},
{2667, "q"},
{2668, "r"},
{2669, "s"},
{2670, "t"},
{2671, "u"},
{2672, "v"},
{2673, "w"},
{2674, "x"},
{2675, "y"},
{2676, "z"},
{2697, "\u200b"},
{2698, "\u2002"},
{2699, "\u2003"},
{2700, "0"},
{2701, "1"},
{2702, "2"},
{2703, "3"},
{2704, "4"},
{2705, "5"},
{2706, "6"},
{2707, "7"},
{2708, "8"},
{2709, "9"},
{2710, "."},
{2711, ","},
{2712, ":"},
{2713, ";"},
{2714, "!"},
{2715, "?"},
{2716, "\u2018"},
{2717, "\u2019"},
{2718, "&"},
{2719, "$"},
{2720, "/"},
{2721, "("},
{2722, ")"},
{2723, "*"},
{2724, "-"},
{2725, "+"},
{2726, "="},
{2727, "\u2032"},
{2728, "\u2033"},
{2729, "\u00b0"},
{2747, "\u200b"},
{2748, "\u2002"},
{2749, "\u2003"},
{2750, "0"},
{2751, "1"},
{2752, "2"},
{2753, "3"},
{2754, "4"},
{2755, "5"},
{2756, "6"},
{2757, "7"},
{2758, "8"},
{2759, "9"},
{2760, "."},
{2761, ","},
{2762, ":"},
{2763, ";"},
{2764, "!"},
{2765, "?"},
{2766, "\u2018"},
{2767, "\u2019"},
{2768, "&"},
{2769, "$"},
{2770, "/"},
{2771, "("},
{2772, ")"},
{2773, "*"},
{2774, "-"},
{2775, "+"},
{2776, "="},
{2777, "\u2032"},
{2778, "\u2033"},
{2779, "\u00b0"},
{2801, "\u0410"},
{2802, "\u0411"},
{2803, "\u0412"},
{2804, "\u0413"},
{2805, "\u0414"},
{2806, "\u0415"},
{2807, "\u0416"},
{2808, "\u0417"},
{2809, "\u0418"},
{2810, "\u0419"},
{2811, "\u041a"},
{2812, "\u041b"},
{2813, "\u041c"},
{2814, "\u041d"},
{2815, "\u041e"},
{2816, "\u041f"},
{2817, "\u0420"},
{2818, "\u0421"},
{2819, "\u0422"},
{2820, "\u0423"},
{2821, "\u0424"},
{2822, "\u0425"},
{2823, "\u0426"},
{2824, "\u0427"},
{2825, "\u0428"},
{2826, "\u0429"},
{2827, "\u042a"},
{2828, "\u042b"},
{2829, "\u042c"},
{2830, "\u042d"},
{2831, "\u042e"},
{2832, "\u042f"},
{2901, "\u0430"},
{2902, "\u0431"},
{2903, "\u0432"},
{2904, "\u0433"},
{2905, "\u0434"},
{2906, "\u0435"},
{2907, "\u0436"},
{2908, "\u0437"},
{2909, "\u0438"},
{2910, "\u0439"},
{2911, "\u043a"},
{2912, "\u043b"},
{2913, "\u043c"},
{2914, "\u043d"},
{2915, "\u043e"},
{2916, "\u043f"},
{2917, "\u0440"},
{2918, "\u0441"},
{2919, "\u0442"},
{2920, "\u0443"},
{2921, "\u0444"},
{2922, "\u0445"},
{2923, "\u0446"},
{2924, "\u0447"},
{2925, "\u0448"},
{2926, "\u0449"},
{2927, "\u044a"},
{2928, "\u044b"},
{2929, "\u044c"},
{2930, "\u044d"},
{2931, "\u044e"},
{2932, "\u044f"},
{3001, "A"},
{3002, "B"},
{3003, "C"},
{3004, "D"},
{3005, "E"},
{3006, "F"},
{3007, "G"},
{3008, "H"},
{3009, "I"},
{3010, "J"},
{3011, "K"},
{3012, "L"},
{3013, "M"},
{3014, "N"},
{3015, "O"},
{3016, "P"},
{3017, "Q"},
{3018, "R"},
{3019, "S"},
{3020, "T"},
{3021, "U"},
{3022, "V"},
{3023, "W"},
{3024, "X"},
{3025, "Y"},
{3026, "Z"},
{3051, "A"},
{3052, "B"},
{3053, "C"},
{3054, "D"},
{3055, "E"},
{3056, "F"},
{3057, "G"},
{3058, "H"},
{3059, "I"},
{3060, "J"},
{3061, "K"},
{3062, "L"},
{3063, "M"},
{3064, "N"},
{3065, "O"},
{3066, "P"},
{3067, "Q"},
{3068, "R"},
{3069, "S"},
{3070, "T"},
{3071, "U"},
{3072, "V"},
{3073, "W"},
{3074, "X"},
{3075, "Y"},
{3076, "Z"},
{3101, "a"},
{3102, "b"},
{3103, "c"},
{3104, "d"},
{3105, "e"},
{3106, "f"},
{3107, "g"},
{3108, "h"},
{3109, "i"},
{3110, "j"},
{3111, "k"},
{3112, "l"},
{3113, "m"},
{3114, "n"},
{3115, "o"},
{3116, "p"},
{3117, "q"},
{3118, "r"},
{3119, "s"},
{3120, "t"},
{3121, "u"},
{3122, "v"},
{3123, "w"},
{3124, "x"},
{3125, "y"},
{3126, "z"},
{3151, "a"},
{3152, "b"},
{3153, "c"},
{3154, "d"},
{3155, "e"},
{3156, "f"},
{3157, "g"},
{3158, "h"},
{3159, "i"},
{3160, "j"},
{3161, "k"},
{3162, "l"},
{3163, "m"},
{3164, "n"},
{3165, "o"},
{3166, "p"},
{3167, "q"},
{3168, "r"},
{3169, "s"},
{3170, "t"},
{3171, "u"},
{3172, "v"},
{3173, "w"},
{3174, "x"},
{3175, "y"},
{3176, "z"},
{3197, "\u200b"},
{3198, "\u2002"},
{3199, "\u2003"},
{3200, "0"},
{3201, "1"},
{3202, "2"},
{3203, "3"},
{3204, "4"},
{3205, "5"},
{3206, "6"},
{3207, "7"},
{3208, "8"},
{3209, "9"},
{3210, "."},
{3211, ","},
{3212, ":"},
{3213, ";"},
{3214, "!"},
{3215, "?"},
{3216, "\u2018"},
{3217, "\u2019"},
{3218, "&"},
{3219, "$"},
{3220, "/"},
{3221, "("},
{3222, ")"},
{3223, "*"},
{3224, "-"},
{3225, "+"},
{3226, "="},
{3227, "\u2032"},
{3228, "\u2033"},
{3229, "\u00b0"},
{3247, "\u200b"},
{3248, "\u2002"},
{3249, "\u2003"},
{3250, "0"},
{3251, "1"},
{3252, "2"},
{3253, "3"},
{3254, "4"},
{3255, "5"},
{3256, "6"},
{3257, "7"},
{3258, "8"},
{3259, "9"},
{3260, "."},
{3261, ","},
{3262, ":"},
{3263, ";"},
{3264, "!"},
{3265, "?"},
{3266, "\u2018"},
{3267, "\u2019"},
{3268, "&"},
{3269, "$"},
{3270, "/"},
{3271, "("},
{3272, ")"},
{3273, "*"},
{3274, "-"},
{3275, "+"},
{3276, "="},
{3277, "\u2032"},
{3278, "\u2033"},
{3279, "\u00b0"},
{3301, "A"},
{3302, "B"},
{3303, "C"},
{3304, "D"},
{3305, "E"},
{3306, "F"},
{3307, "G"},
{3308, "H"},
{3309, "I"},
{3310, "J"},
{3311, "K"},
{3312, "L"},
{3313, "M"},
{3314, "N"},
{3315, "O"},
{3316, "P"},
{3317, "Q"},
{3318, "R"},
{3319, "S"},
{3320, "T"},
{3321, "U"},
{3322, "V"},
{3323, "W"},
{3324, "X"},
{3325, "Y"},
{3326, "Z"},
{3401, "a"},
{3402, "b"},
{3403, "c"},
{3404, "d"},
{3405, "e"},
{3406, "f"},
{3407, "g"},
{3408, "h"},
{3409, "i"},
{3410, "j"},
{3411, "k"},
{3412, "l"},
{3413, "m"},
{3414, "n"},
{3415, "o"},
{3416, "p"},
{3417, "q"},
{3418, "r"},
{3419, "s"},
{3420, "t"},
{3421, "u"},
{3422, "v"},
{3423, "w"},
{3424, "x"},
{3425, "y"},
{3426, "z"},
{3427, "\ufffd"},
{3428, "\ufffd"},
{3429, "\ufffd"},
{3501, "A"},
{3502, "B"},
{3503, "C"},
{3504, "D"},
{3505, "E"},
{3506, "F"},
{3507, "G"},
{3508, "H"},
{3509, "I"},
{3510, "J"},
{3511, "K"},
{3512, "L"},
{3513, "M"},
{3514, "N"},
{3515, "O"},
{3516, "P"},
{3517, "Q"},
{3518, "R"},
{3519, "S"},
{3520, "T"},
{3521, "U"},
{3522, "V"},
{3523, "W"},
{3524, "X"},
{3525, "Y"},
{3526, "Z"},
{3601, "a"},
{3602, "b"},
{3603, "c"},
{3604, "d"},
{3605, "e"},
{3606, "f"},
{3607, "g"},
{3608, "h"},
{3609, "i"},
{3610, "j"},
{3611, "k"},
{3612, "l"},
{3613, "m"},
{3614, "n"},
{3615, "o"},
{3616, "p"},
{3617, "q"},
{3618, "r"},
{3619, "s"},
{3620, "t"},
{3621, "u"},
{3622, "v"},
{3623, "w"},
{3624, "x"},
{3625, "y"},
{3626, "z"},
{3697, "\u200b"},
{3698, "\u2002"},
{3699, "\u2003"},
{3700, "0"},
{3701, "1"},
{3702, "2"},
{3703, "3"},
{3704, "4"},
{3705, "5"},
{3706, "6"},
{3707, "7"},
{3708, "8"},
{3709, "9"},
{3710, "."},
{3711, ","},
{3712, ":"},
{3713, ";"},
{3714, "!"},
{3715, "?"},
{3716, "\u2018"},
{3717, "\u2019"},
{3718, "&"},
{3719, "$"},
{3720, "/"},
{3721, "("},
{3722, ")"},
{3723, "*"},
{3724, "-"},
{3725, "+"},
{3726, "="},
{3727, "\u2032"},
{3728, "\u2033"},
{3729, "\u00b0"},
{3801, "A"},
{3802, "B"},
{3803, "C"},
{3804, "D"},
{3805, "E"},
{3806, "F"},
{3807, "G"},
{3808, "H"},
{3809, "I"},
{3810, "J"},
{3811, "K"},
{3812, "L"},
{3813, "M"},
{3814, "N"},
{3815, "O"},
{3816, "P"},
{3817, "Q"},
{3818, "R"},
{3819, "S"},
{3820, "T"},
{3821, "U"},
{3822, "V"},
{3823, "W"},
{3824, "X"},
{3825, "Y"},
{3826, "Z"},
{3901, "a"},
{3902, "b"},
{3903, "c"},
{3904, "d"},
{3905, "e"},
{3906, "f"},
{3907, "g"},
{3908, "h"},
{3909, "i"},
{3910, "j"},
{3911, "k"},
{3912, "l"},
{3913, "m"},
{3914, "n"},
{3915, "o"},
{3916, "p"},
{3917, "q"},
{3918, "r"},
{3919, "s"},
{3920, "t"},
{3921, "u"},
{3922, "v"},
{3923, "w"},
{3924, "x"},
{3925, "y"},
{3926, "z"},
/* leave this entry as last - it's a sentinel */
{   -1, "" }
};
